#!/usr/bin/perl -w -I/usr/sausalito/perl -I.
# Authors:
# Brian N. Smith  -      NuOnce Networks      - http://www.nuonce.net
# Michael Stauber - Stauber Multimedia Design - http://www.solarspeed.net
# Copyright 2006, NuOnce Networks & Stauber Multimedia Design. All rights reserved.

use CCE;
use Sauce::Util;
use Sauce::Service;

my $cce = new CCE;
$cce->connectfd();

my $oid = $cce->event_oid();
my $obj = $cce->event_object();

my @oids = $cce->find('System');
if (!defined($oids[0])) {
	print STDERR "Sorry, no System object in CCE found!\n";
	exit 0;
}

my $yumguiConf    = "/etc/yumgui.conf";
my $yumguiCrontab = "/etc/cron.d/yumgui.crontab";

my ($ok, $yumguiValues) = $cce->get($oids[0], "nusolYum");

if ($ok) {
    yumguiWriteConf(
	$yumguiValues->{'yumguiEMAIL'},
        $yumguiValues->{'yumguiEMAILADDY'}
        );

    yumguiSetCrontab(
        $yumguiValues->{'yumUpdateSU'},
        $yumguiValues->{'yumUpdateMO'},
        $yumguiValues->{'yumUpdateTU'},
        $yumguiValues->{'yumUpdateWE'},
        $yumguiValues->{'yumUpdateTH'},
        $yumguiValues->{'yumUpdateFR'},
        $yumguiValues->{'yumUpdateSA'},
        $yumguiValues->{'yumUpdateTime'},
        $yumguiValues->{'autoupdate'}
        );
}

$cce->bye('SUCCESS');
exit(0);

##
## Sort the stuff for the crontab file
##

sub yumguiSetCrontab {
	my $yumUpdateSU   = shift;
	my $yumUpdateMO   = shift;
	my $yumUpdateTU   = shift;
	my $yumUpdateWE   = shift;
	my $yumUpdateTH   = shift;
	my $yumUpdateFR   = shift;
	my $yumUpdateSA   = shift;
	my $yumUpdateTime = shift;
	my $autoupdate    = shift;

	($h, $m) = split(':', $yumUpdateTime);
    	my $crontab_entry = "$m $h * * ";

    	my $tmp_crontab_entry =
        ($yumUpdateSU eq 1 ? "0," : "")
      	. ($yumUpdateMO eq 1 ? "1," : "")
      	. ($yumUpdateTU eq 1 ? "2," : "")
      	. ($yumUpdateWE eq 1 ? "3," : "")
      	. ($yumUpdateTH eq 1 ? "4," : "")
      	. ($yumUpdateFR eq 1 ? "5," : "")
      	. ($yumUpdateSA eq 1 ? "6," : "");

    if ($autoupdate eq "On") {
    	$tmp_crontab_entry =~ s/,$//;
    	$tmp_crontab_entry = "*" if length($tmp_crontab_entry) < 1;
    	$crontab_entry .= $tmp_crontab_entry . " root /usr/sausalito/handlers/nuonce-solarspeed/yum/yum_update\n";
    	chomp($crontab_entry);
    	open(CRON, ">$yumguiCrontab") || die "Can't write to crontab";
    	print CRON "# DO NOT EDIT! THIS FILE IS GENERATED AUTOMATICALLY THROUGH THE GUI!\n";
    	print CRON $crontab_entry;
    	print CRON "\n";
    	print CRON "\n";
    	close CRON;
    }
    if ($autoupdate eq "Off") {
	unlink $yumguiCrontab; 
    }
    Sauce::Util::chmodfile(00644, $yumguiCrontab);
    Sauce::Service::service_run_init('crond', 'restart');
}


##
## yumguiWriteConf
## Saves yumgui configuration into /etc/yumgui.conf
##

sub yumguiWriteConf {
    my $yumguiEMAIL                 = shift;
    my $yumguiEMAILADDY             = shift;

    if ($yumguiEMAIL eq "1") {
	open(CONF, ">$yumguiConf") || die "Can't write to configuration file";
    	print CONF "#!/bin/sh
###############################################################
## YUM-GUI 						     ##
##                                                           ##
## Main Configuration File                                   ##
##                                                           ##
## DO NOT EDIT THIS FILE!                                    ##
##                                                           ##
###############################################################

MAILTO=\"$yumguiEMAILADDY\";

";
close CONF;
	Sauce::Util::chmodfile(00644, $yumguiConf);
    }
    else {
	unlink $yumguiConf;
    }
}

